This class is the engine of the program. It encapsulates all the methods to do with managing scores, commands and player states(dead/alive).

Revision:
9:54c620f7d736
Parent:
8:93f18f1c1241
Child:
11:48190450b7e5
--- a/Operator.h	Fri Apr 21 10:55:23 2017 +0000
+++ b/Operator.h	Sun Apr 23 16:36:37 2017 +0000
@@ -27,12 +27,14 @@
 
  /**
      * @brief generates a random interger to be used in the display class to represent an instruction
+     * @param Display, N5110
      * @return void random interger
      */
     int random_instruction(Display &display, N5110 &lcd);  
 
 /** 
     *  @brief Method to test the player 
+    *  @param the player to test, Controller, Display, N5110
     *  @return true/false on Success
     */
     bool test_player(int nextplayer, Controller &ctrl, Display &display, N5110 &lcd);
@@ -43,30 +45,46 @@
     */
     bool check_dead();
 
 /** Method performed when the user performs the RIGHT instruction on time, score is increased, lighting and sound performed.*/
     void Correct(int next_player, Controller &ctrl);  
 
 /** Method performed when the user performs the WRONG instruction on time */
     void InCorrect(int next_player, Controller &ctrl);  
 
-/** Methord to set up array of Player stut */
-
+/** Method to set up array of Player strut 
+    *  @param the number of players to set up
+    */
     void setup_players(int num_players);
             
 /** Methord performed when the user is too slow or performs the wrong instruction, score is displayed, game ends */
     void Game_Over(Controller &ctrl, N5110 &lcd);
     
-/** Methord performed to chech which user it is and to swap after exch ten*/
+/** Method performed to chech which user it is and to swap after exch ten*/
     int check_next_player(int next_player, N5110 &lcd, Controller &ctrl, Display display);
     
 private:  
     /** This methord displays and assesses score and display a performace rating for user to see.*/
     void Assessment(N5110 &lcd, int score); 
  
     /** This methord displays and assesses scores when multi-player*/ 
    void MultiResults(N5110 &lcd);
   
-    
+    /** This method counts down the next player 
+    *  @param Controller, N5110, the player to display next turn
+    */ 
+   void DisplayNextPlayer(Controller &ctrl, N5110 &lcd, int thenext_player);
+   
+       
     float freq_change;
     int score; // <score to indentify users progress through game
     Player myplayers[1]; //setup players
@@ -43,30 +45,46 @@
     bool check_dead();
 
-/** Method performed when the user performs the RIGHT instruction on time, score is increased, lighting and sound performed.*/
+/** Method performed when the user performs the RIGHT instruction on time, score is increased, lighting and sound performed.
+    *  @param the player, Controller
+    */
     void Correct(int next_player, Controller &ctrl);  
 
@@ -43,30 +45,46 @@
     void Correct(int next_player, Controller &ctrl);  
 
-/** Method performed when the user performs the WRONG instruction on time */
+/** Method performed when the user performs the WRONG instruction on time 
+    *  @param the player, Controller
+    */
     void InCorrect(int next_player, Controller &ctrl);  
 
@@ -43,30 +45,46 @@
     void setup_players(int num_players);
             
-/** Methord performed when the user is too slow or performs the wrong instruction, score is displayed, game ends */
+/** Method performed when the user is too slow or performs the wrong instruction, score is displayed, game ends 
+    *  @param the player, Controller
+    */
     void Game_Over(Controller &ctrl, N5110 &lcd);
     
@@ -43,30 +45,46 @@
     
 private:  
-    /** This methord displays and assesses score and display a performace rating for user to see.*/
+    /** This methord displays and assesses score and display a performace rating for user to see.
+    *  @param N5110, score
+    */    
     void Assessment(N5110 &lcd, int score); 
  
@@ -43,30 +45,46 @@
     void Assessment(N5110 &lcd, int score); 
  
-    /** This methord displays and assesses scores when multi-player*/ 
+    /** This methord displays and assesses scores when multi-player
+    *  @param N5110
+    */
    void MultiResults(N5110 &lcd);
   